/**
 * @用途
 * @author 黄敏
 * @创建时间 2022-08-17 15:25
 **/

declare namespace User {
	interface NewContactWay {
		type: 'email' | 'phone' //类型
		info: string //联系方式
		plugin_id?: string
		is_vaild?: 0 | 1 //是否校验
		country_id?: number //国家ID
		port?: number //端口
		host?: string //主机
	}

	//用户的联系方式
	interface ContactWay extends Required<NewContactWay> {
		id: number
		user_id: number //用户ID
	}

	//cm中的用户信息
	interface CmUserInfo {
		id: number
		type: number
		username: string //全称
		nickname: string //缩写
		other_name: string //中文名字
		status: 0 | 1 //状态
		audit_status: 0 | 1 //认证状态
		fso: 0 | 1 | 2 | 3 | 4 | 5 | 6 //办公司地区
		update_time: number //更新时间
		delete_time: number //删除时间
		create_time: number //创建时间
		file_path: string //路径
		thumb_path: string //路径
		//联系方式
		infos: ContactWay[]
		lat?: number | string
		lng?: number | string
		angle?: number
	}

	// 用户权限数据格式
	interface UserAuth {
		status?: number // 用户状态, 0-冻结, 1-正常, 2-表示已删除（不能被分配axon）
		is_developer?: number //是否是开发者
		is_owner?: number // 是否项目所有人，0-普通会员 1-项目所有人，2-管理员，
		auths?: null | { excepts?: string[] } // 权限详情
	}

	interface ProjectListItem {
		auths: { excepts?: string[] } | null
		end_time: number //到期时间
		create_time: number
		descr: string
		file_path: string
		is_default: 0 | 1
		is_owner: 0 | 1 | 2 // 是否项目所有人，1-项目所有人，2-管理员
		is_developer: 0 | 1 //是否是开发者
		lock_user_ids: number[] // 锁定用户ID（搜索框右侧展示）
		name: string
		project_id: number
		status: 0 | 1 | 2 // 用户状态, 0-冻结, 1-正常, 2-表示已删除（不能被分配axon）
		thumb_path: string
		user_id: string
	}

	//项目详细
	interface Project {
		id: number
		name: string
		descr: string
		status: number
		creater_id: number
		update_time: number
		delete_time: number
		create_time: number
		limits: number
		file_id: number
		thumb_id: number
		end_time: number
		file_path: string
		thumb_path: string
	}

	//激活码信息
	interface ActiveationKey {
		id: number
		code: string //激活码
		project_id: number //关联项目ID
		create_time: number //创建时间
		user_id: number //用户ID
		limit: number //限制人数
		end_time: number //到期时间
	}

	//用户信息比cm的用户信息多了项目id，和token
	interface UserInfo extends CmUserInfo {
		project_id: number
		token: string
		project_list: ProjectListItem[]
	}

	//服务器返回的 CM项目格式
	interface CMItem {
		id: number
		project_id: number //项目id
		user_id: number //用户id
		// alias_name: string,//用户名称缩写
		user: CmUserInfo
		auths: { excepts?: string[] } | null
		status: 0 | 1 | 2 // 项目状态 0-冻结, 1-正常, 2-表示已删除（不能被分配axon）
		is_owner: 0 | 1 | 2 // 是否项目所有人，1-项目所有人，2-管理员
		is_developer: 0 | 1 //是否是开发者
		lock_user_ids: number[] // 锁定用户ID（搜索框右侧展示）
	}
}

declare namespace Crawler {

	interface Anchor {
		type: string //联系方式类型  //linkedin
		info: string //联系地址  //https://www.linkedin.com/in/cecilia-li-a7a912162/
		//是否是付费用户
		premium?: 0 | 1
		//同步数据使用
		origin_id?: number | string //来源id,当来源id不为空时，也是当前info的唯id
		origin_image?: string //来源图片
		origin_name?: string //来源里的name,在contact上时，是源contact_name,在company时是源company name;
		origin_address?: string //来源里的地址
		sync_time?: number //最后同步来源的时间
		country_id?: number
		friends?: ContactAnchorFriends[] //与f2是好友关系，这里放的是f2在该锚的上的info
	}

	interface ContactAnchorFriends {
		info: string //联系地址
		origin_id?: number | string //来源id,当来源id不为空时，也是当前info的唯id
		origin_image?: string //来源图片
		origin_name?: string //来源里的name,在contact上时，是源contact_name,在company时是源company name;
	}

	interface Method {
		method: string //使用的方法
		test: string
	}

	//URL匹配对象
	interface UrlMatch extends Method {
		//匹配字符，如果使用正则，请使用/开头，/结尾 如 '/linkedin\.com\/in\//'
		rules: string[],
		//匹配类型，url:表示通过url获取数据，dom:表示通过注入获取数据
		type: 'url' | 'dom'
	}

	interface EyeMatch extends Method {
		name: string
	}

	interface Employee extends Method {
		//是否是翻页数据
		isPaging?: boolean
	}

	interface AnchorConfig extends Method {
		regular: string, //匹配规则，正则表达式，用于判断锚格式是否正确
		exclude_regular: string, //排除规则
	}

	/* AccountConfig的method返回的用户状态*/
	interface UserAccountState {
		is_login: boolean, //是否登录
		is_pay?: boolean,	//是否付费
	}

	interface AccountConfig extends Method { //Methods 返回 Crawler.UserAccountState
		login_url: string,
		pay_url: string,
	}

	interface AnchorsConfig {
		type: string, //锚类型,一旦发布，不可修改
		regular_uid:string //匹配id规则
		icon: string, //使用的图标
		color: string, //图标的颜色

		//公司锚
		company?: AnchorConfig
		//联系人锚
		contact?: AnchorConfig
		//产品锚
		product?: AnchorConfig

		//共同好友
		mutual_friends?: Method
		//关系
		relationship?: Method
	}

	//爬虫扩展
	interface ServerExtension {

		//扩展标题
		title: string
		remark: string,
		search_engine?: {
			language: f2.Language,
		},

		//用户账户配置
		account_config?: AccountConfig
		//扩展ID
		id: number
		//使用域
		domain: string[]


		anchors?: AnchorsConfig

		//关联的联系方式类型
		info_type?: f2.info.Type

		//当前版本
		js_url: string

        //使用方式 0-通用 1-手动选择
    use_type: number

		//分类ID
		category_ids: number[]

		//选中状态 0-未选中 1-选中
		active_select: 0|1

		//匹配Url规则对象
		matchs: UrlMatch[]

		is_login?: Method,

		account_eye?: {
			list?: EyeMatch
			link?: EyeMatch //google/baidu 搜索连接
			image?: EyeMatch //google/baidu 搜索图片
		}

		contact_eye?: {
			list?: EyeMatch
			link?: EyeMatch //google/baidu 搜索连接
			image?: EyeMatch //google/baidu 搜索图片
		}

		//通过联系方式更新，info_type值不能为空
		account_info?: Method
		contact_info?: Method

		employee?: {
			//通过联系方式获取员工数据,info_type值不能为空
			info?: Employee

			//通过公司名称获取员工数据
			company_name?: Employee

			//通过asnumber获取员工数据
			asnumber?: Employee

			//通过domain获取员工数据
			domain?: Employee
		}

		mutual_friends?: Method

		//关系
		relationship?: Method
		/*
		* 	interface FriendInfo {
				isFriend: boolean //是否是好友
				isPending?: boolean //是否已经发送加好友请求，并且正在等待通过
				message_id?: number | string //发消息ID,如果有
				encrypt_uid: string //加密过的字符串id,目前只有linkedin会有用
				uid?: number | string //当前登录者uid
	}
		*
		* */
	}

	interface Code {
		[fun: string]: Function
	}

	interface Extension extends ServerExtension {
		code?: Code
	}

	//营业时间
	interface BusinessHour {
		begin: string
		end: string
		type?: number //当天营业状态 0休息 1营业
		num: number
		status?: number
		ball?: boolean
		cek?: boolean
	}

	type BusinessHours = BusinessHour[]

	//媒体数据类型
	enum MediaType {
		link,
		excel,
		ppt,
		pdf,
		doc,
		image
	}

	//媒体
	interface Media {
		file_path?: string //当data_type是1，2，3，4时，存放文件路径
		media_page: string //当media_type是0 时，存放媒体网址
		title?: string //标题
		description?: string //备注
		data_type: MediaType //0媒体链接,1 excel,2 ppt,3pdf,4doc,5图片
		link_type: string
	}

	//数据类型
	type DataType = 'contact' | 'company'

	interface FriendInfo {
		isFriend: boolean //是否是好友
		isPending?: boolean //是否已经发送加好友请求，并且正在等待通过
		message_id?: number | string //发消息ID,如果有
		encrypt_uid: string //加密过的字符串id,目前只有linkedin会有用

		user: ContactAnchorFriends,
	}


	/*联系教育经历*/
	interface Education {
		college: string //学校名称
		start_date?: {
			//开始日期`
			year?: number
			month?: f2.Month | 0
		}
		end_date?: {
			//结束日期
			year?: number
			month?: f2.Month | 0
		}
		degree_name?: string //学位
		study?: string //专业
		descr?: string //描述
	}

	//工作经历
	interface Work {
		company: string //公司名称
		company_id?: number //公司Id
		location?: string //工作地点
		positions?: string //职位，多个职位用分号分隔
		descr?: string //描述
		unique_id?: string //唯一id，与来源id格式相同但只用与验证数据的唯一性，相同id,爬出来的数据应该一模一样；
		start_date?: {
			//入职日期
			year?: number
			month?: f2.Month | 0
		}
		end_date?: {
			//离职日期
			year?: number
			month?: f2.Month | 0
		}
		is_quit: boolean //离职状态，
		dept_id?: string // 所属部门
	}

	//联系人地址
	interface ContactAddress {
		type: 'work' | 'residence' | 'unknown' //类型，工作或住所
		address: string //地址
		latitude?: number //纬度
		longitude?: number //经度
	}

	//公司地址
	interface CompanyAddress {
		name?: string // 地址名称
		headquarter?: boolean // 是否是总部
		/*国家与详细地址，必须有要有一项*/
		country: string // 国家代码
		city?: string // 城市
		address: string // 详细地址
		latitude?: number // 纬度
		longitude?: number // 经度
		country_id?: number
		verified?: boolean //地址验证无误的
	}

	//公司图片
	interface CompanyImg {
		type: 'logo' | 'street' | 'banner'
		url: string
	}

	enum PhoneType {
		固定电话 = 0,
		手机,
		传真,
		不确定
	}

	interface ContactInfo {
		type: f2.info.Type //联系方式类型
		info: string //联系地址

		friend?: 0 | 1 //是否是好友，该字段只在要把联系方式改为好友时是使用，只用于传参，不用于展示
		//linkedin专用
		premium?: 0 | 1 //用于linkedin 是否是高级账号

		//手机专用
		ext?: string | number //分机号，只有电话存在该字段
		phone_type?: PhoneType //如果是电话时的电话类型

		//同步数据使用
		unique_id?: string //来源id,当来源id不为空时，也是当前info的唯id
		origin_name?: string //来源里的name,在contact上时，是源contact_name,在company时是源company name;
		origin_address?: string //来源里的地址
		country_id?: number
		plugin_id?: string
		remark?: string //备注
	}

	interface ContactsName {
		first_name: string //名
		last_name: string //姓
		lang?: f2.Language //语言
		gender?: f2.Gender //性别
	}

	//采集器联系人格式
	interface Contact {
		origin: string
		update_time: number //采集时间+
		completed: boolean //数据是否完整
		plugin_id: string //旧版用于验证的id
		contacts_names: ContactsName[]
		birth_year: number //生日年份
		birth_month: f2.Month | 0 //生日月份
		birth_day: number //生日天
		gender?: f2.Gender //性别
		geo_region?: string //地理区域，可能是城市，国家或组合
		country?: string //国家简写
		remark?: string //备注、简介
		addresses: ContactAddress[] //地址
		educations: Education[] //教育
		works: Work[] //工作经历
		imgs: string[] //图片
		tags?: string[]
		infos: ContactInfo[]
		medias: Media[] //联系人媒体
		anchors: Anchor[]
	}

	//采集器公司格式
	interface Company {
		origin: string //数据的来源
		update_time: number //采集时间
		completed: boolean //数据完整性，数据是否已经采集完整,默认为不完整
		plugin_id: string //旧版用于验证的id  aswhois-AS34321
		name: string //company 名称
		aliases: string[] //别名
		founders?: {
			//创始人
			name: string //创始人姓名
			origin_id?: string //oid
		}[]
		founded?: string //创建时间 格式：2018-08-01或，2018或2018-08
		business_hours?: BusinessHours //营业时间
		country: string //国家简写
		geo_region?: string //地理区域，可能是城市，国家或组合
		employees?: string //# 公司规模
		staffCount?: number //# 公司人数
		industrys: string[] //行业,一个数组，可以有多个行业
		specialties: string[] //领域特长
		as_numbers: string[] //as_numbers号,可以有多个as号

		infos: ContactInfo[]

		domains: string[] // 域名,域名
		anchors: Anchor[]
		addresses: CompanyAddress[] //地址
		imgs: CompanyImg[] // 图片
		stock: {
			// 股票数据
			stock_code: string // 股票代码
			market_name: string // 上市市场名字
		}[]
		partners: string[] // 合伙人
		remark?: string // 简介
		godaddy?: boolean
		registeredCapital?: string | number //注册资本 数字
		currencyUnit?: string //注册币种 'USD' | 'GBP' | 'AUD' | 'JPY' | 'EUR' | 'SGD' | 'KRW' | 'CNY' | 'INR' | 'HKD' | 'TWD' | ''|'美元'|'元'等
		registeredTime?: number //公司注册时间
	}


	//google搜索结果或其它url的信息
	interface SearchUrlInfo {
		title: string
		url: string
		description: string
		$key?: string //用于标识唯一key
	}

	type MediaInfoType =
			| 'email'
			| 'phone'
			| 'qq'
			| 'skype'
			| 'wechat'
			| 'weibo'
			| 'linkedin'
			| 'facebook'
			| 'youtube'
			| 'pinterest'
			| 'instagram'
			| 'twitter'
			| 'quora'
			| 'tianyancha'
			| 'qcc'
			| 'qixin'
			| 'opencorporates'
			| 'jd'
			| 'alibaba'
			| 'tmall'
			| 'ebay'
			| 'amazon'
			| 'zhihu'
			| 'wsj'

	interface MediaInfo {
		type: MediaInfoType
		info: string | number
	}

	/*
	 * 唯一标识，用于查询关联的contact或account,
	 * 并且把对应数据显示在浏览器右侧插件上
	 *
	 * */
	interface ResultUniques {
		//唯一数据
		type: DataType
		unique_id?: string //唯一id
		info?: string | number //联系方式
		domain?: string //域名
	}


	//可翻页爬虫批处理
	interface Paging {
		//批处理标题
		title: string,
		//唯一标识
		uid: string,

		//获取数据的接口，如果url就是获取数据的接口，那url与api的接一样
		// /voyager/api/search/blended?origin=DISCOVER_FROM_SEARCH_HOME&count=10
		api: string

		//使用的方法名
		method: string,

		//可变参数有效范围
		//参数配置
		param_name: string //参数名称
		param_start: number //参数开始值
		param_step: number //递增步长

		total: number //结果总数
		page_size: number //一页的条数

	}

	//通用结果值
	interface Result {
		contact?: Contact, //当结果是一个联系人的主页时， 如：https://www.linkedin.com/in/alexwang4/
		company?: Company,  //当结果是一个公司的主页时， 如：https://www.linkedin.com/company/hewlett-packard-enterprise/
		contacts?: Contact[] //联系人数组
		companys?: Company[] //公司数组
		paging?: Paging //批处理任务
		results?: SearchUrlInfo[] //google搜索结果或其它结果url的信息
		mediaInfos?: MediaInfo[] //媒体联系数据。用于在获取dom时，提示的联系方式
	}


	//linkedin 统计
	//统计类型
	enum LinkedinStatisticsType {
		contact_detail = 1, //访问详情
		search, //普通搜索
		sales_search, //sales搜索
		connect, //加好友次数
		message, //发送message次数
		friend_verify //验证好友次数
	}

	//linkedin 统计
	//统计类型
	interface LinkedinStatistics {
		time: number //记录时间
		type: LinkedinStatisticsType
	}

	/**
	 * 共同好友数据结构
	 * */
	interface MutualFriends {
		uid: string
		num: number //数量
		text: string //提示
		list: Contact[]
	}

	// 地图页面地点数据
	interface MapPlace {
		name: string
		address: string
		domain: string
		phone: string
		location: string
		imgs: string[]
		latitude?: number
		longitude?: number
	}

	interface GoogleImg {
		img: string
		width: number
		height: number
		thumb: string
		thumb_width: number
		thumb_height: number
		//type: res.st,
		href: string
		title: string
		id: string
		domain: string
	}

	//员工结果数据，
	interface EmployeeResult {
		contacts: Crawler.Contact[]
		resultUrl?: string
		suggestPay?: boolean //（是否建议付费）付费否可以获取更多数据，
		paySite?: string //如果建议付费，给出付费的网址
	}

	//domain员工结果数据，
	interface DomainEmployeeResult {
		list: Crawler.SearchUrlInfo[],
		url: string
	}

	//员工可翻页结果数据
	interface EmployeePagingResult {
		paging: Paging //批处理任务
		resultUrl?: string
		suggestPay?: boolean //（是否建议付费）付费否可以获取更多数据，
		paySite?: string //如果建议付费，给出付费的网址
	}

}

declare namespace f2 {
	//用于标识唯一key
	interface $Key {
		$key?: string
	}

	namespace tab {
		interface Browser {
			id: number //直接在已有的tab上运行
			url: string //url地址
			favicon: string //图标
			title: string //标题
			isError?: boolean //是否有错误
			isLoading: boolean //是否在加载
			auto3w?: boolean //自动添加www,当无添加www无法打开时会自动添加www
			companyOrigin?: { companyId: number; url: string } | null //公司数据源，
			focus: boolean //是否要获取焦点
			useBrowserView?: boolean, //直接使用BrowserView打开，不需要浏览器界面，一般用于打开原生页面，或者一些不需要浏览器插件的页面
			sourceTab?: {
				// 是否来源于另一个tab
				id: number // 来源Tab ID
				url: string // 来源Tab Url
			}
		}

	}

	type Month = 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 | 11 | 12

	//性别
	enum Gender {
		woman,
		man
	}

	type Language =
			| 'en'
			| 'cn'
			| 'ru'
			| 'sq'
			| 'ar'
			| 'am'
			| 'az'
			| 'ga'
			| 'et'
			| 'or'
			| 'eu'
			| 'be'
			| 'bg'
			| 'is'
			| 'pl'
			| 'bs'
			| 'fa'
			| 'af'
			| 'tt'
			| 'da'
			| 'de'
			| 'fr'
			| 'tl'
			| 'fi'
			| 'fy'
			| 'km'
			| 'ka'
			| 'gu'
			| 'kk'
			| 'ht'
			| 'ko'
			| 'ha'
			| 'nl'
			| 'ky'
			| 'gl'
			| 'ca'
			| 'cs'
			| 'kn'
			| 'co'
			| 'hr'
			| 'ku'
			| 'la'
			| 'lv'
			| 'lo'
			| 'lt'
			| 'lb'
			| 'rw'
			| 'ro'
			| 'mg'
			| 'mt'
			| 'mr'
			| 'ml'
			| 'ms'
			| 'mk'
			| 'mi'
			| 'mn'
			| 'bn'
			| 'my'
			| 'hmn'
			| 'xh'
			| 'zu'
			| 'ne'
			| 'no'
			| 'pa'
			| 'pt'
			| 'ps'
			| 'ny'
			| 'ja'
			| 'sv'
			| 'sm'
			| 'sr'
			| 'st'
			| 'si'
			| 'eo'
			| 'sk'
			| 'sl'
			| 'sw'
			| 'gd'
			| 'ceb'
			| 'so'
			| 'tg'
			| 'te'
			| 'ta'
			| 'th'
			| 'tr'
			| 'tk'
			| 'cy'
			| 'ug'
			| 'ur'
			| 'uk'
			| 'uz'
			| 'es'
			| 'iw'
			| 'el'
			| 'haw'
			| 'sd'
			| 'hu'
			| 'sn'
			| 'hy'
			| 'ig'
			| 'it'
			| 'yi'
			| 'hi'
			| 'su'
			| 'id'
			| 'jw'
			| 'yo'
			| 'vi'
			| ''

	namespace info {
		type Type =
				| 'email'
				| 'phone'
				| 'qq'
				| 'skype'
				| 'telegram'
				| 'wechat'
				| 'icq'
				| 'whatsapp'
				| 'line'


		interface Config {
			syncData?: Boolean //是否可以通过联系方式同步数据
			icon: string //图标
			color: string //颜色
			filter?: RegExp //过滤正则，过滤掉不正确的格式
			regular: RegExp //匹配，用于验证 用于 validate
			id?: RegExp //提取id的正则，用于getId
			target?: string //a 连接的target
			hrefPrefix: string //连接地址 @url@ 替换传入的url,用于getLinkedin
		}
		interface TypeConfig extends Config {
			type?: Type
		}

		//联系方式
		interface Info extends $Key, Crawler.ContactInfo {
			id?: number

			country_id?: number //国家id
			branch_id?: number //地点id
			contact_id?: number //关联联系人id  (如果是联系人的联系方式)
			company_id?: number //关联公司id    (如果是公司的联系方式)
			update_time?: number //更新时间
			create_time?: number //创建时间
			check_user_id?: number //校验用户ID,

			edit_li?: 0 | 1 //是否刷新过linkedin密文

			//同步数据使用
			sync_time?: number //最后同步来源的时间
			route_status?: 0 | 1 //是否查询过
			status?: 0 | 1 | 2 //状态 0未验证，1可用，2不可用
		}
	}

}

declare const PORT: string
declare const DEV_ROOT: string
declare const TEST_SERVER: string
