type ValueOf<T> = T[keyof T];
export declare const MezzFileType: Readonly<{
    未知: 0;
    图片: 1;
    音频: 2;
    视频: 3;
    word: 4;
    excel: 5;
    ppt: 6;
    pdf: 10;
    eml: 11;
}>;
export declare const LiveActionType: Readonly<{
    进入首页: 0;
    进入公司: 1;
    在公司里打开联系人: 2;
    打开联系人: 3;
    联系人留mezz: 4;
    在公司里留mezz: 5;
    完成axon: 6;
}>;
export declare const MqttStatus: Readonly<{
    noConnect: 0;
    connected: 1;
    close: 2;
    error: 3;
}>;
interface AtToHtmlConfig {
    cmClass?: string;
    contactClass?: string;
    accountClass?: string;
    ibClass?: string;
    obClass?: string;
}
interface LiveActionConfig {
    contact?: {
        id: number;
        name: string;
    };
    account?: {
        id: number;
        name: string;
    };
    mezz?: string;
}
interface matchSortOption {
    same: number;
    company_info: Object;
    sort: number;
    sortype: number;
    [name: string]: any;
}
interface Perform {
    (cb?: () => void | Promise<any>): void;
    timeoutId: any;
    clear(): void;
}
declare function isDev(): boolean;
declare function trim(str: string, s?: string): string;
declare function ltrim(str: string, s?: string): string;
declare function rtrim(str: string, s?: string): string;
/**
 * 是否是普通JavaScript对象。只返回boolean
 */
declare function isObject(obj: any): boolean;
/**
 * 是否是中文
 * @str
 * @include //包含中文
 * */
declare function isChn(str: string, include?: boolean): boolean;
/**
 * 是否是英文名字
 * @str
 * */
declare function isEnn(str: string): boolean;
declare function compare(property: string): (a: any, b: any) => number;
/**
 * 替换字符串中的重音字符
 * @param str
 */
declare function normalizeChars(str: string): string;
export declare function htmlToDom(html: string, tag?: keyof HTMLElementTagNameMap): HTMLObjectElement | HTMLElement | HTMLAnchorElement | HTMLParagraphElement | HTMLQuoteElement | HTMLAreaElement | HTMLAudioElement | HTMLBaseElement | HTMLBodyElement | HTMLBRElement | HTMLButtonElement | HTMLCanvasElement | HTMLTableCaptionElement | HTMLTableColElement | HTMLDataElement | HTMLDataListElement | HTMLModElement | HTMLDetailsElement | HTMLDialogElement | HTMLDivElement | HTMLDListElement | HTMLEmbedElement | HTMLFieldSetElement | HTMLFormElement | HTMLHeadingElement | HTMLHeadElement | HTMLHRElement | HTMLHtmlElement | HTMLIFrameElement | HTMLImageElement | HTMLInputElement | HTMLLabelElement | HTMLLegendElement | HTMLLIElement | HTMLLinkElement | HTMLMapElement | HTMLMenuElement | HTMLMetaElement | HTMLMeterElement | HTMLOListElement | HTMLOptGroupElement | HTMLOptionElement | HTMLOutputElement | HTMLPictureElement | HTMLPreElement | HTMLProgressElement | HTMLScriptElement | HTMLSelectElement | HTMLSlotElement | HTMLSourceElement | HTMLSpanElement | HTMLStyleElement | HTMLTableElement | HTMLTableSectionElement | HTMLTableCellElement | HTMLTemplateElement | HTMLTextAreaElement | HTMLTimeElement | HTMLTitleElement | HTMLTableRowElement | HTMLTrackElement | HTMLUListElement | HTMLVideoElement;
declare class Util {
    trim: typeof trim;
    rtrim: typeof rtrim;
    ltrim: typeof ltrim;
    isDev: typeof isDev;
    isObject: typeof isObject;
    isChn: typeof isChn;
    isEnn: typeof isEnn;
    compare: typeof compare;
    normalizeChars: typeof normalizeChars;
    htmlToDom: typeof htmlToDom;
    devlog(...data: any): void;
    /**
     * 创建一个纯函数的缓存版本。
     */
    cached(fn: Function): (str: string, s2?: string) => any;
    sameText(str1: string, str2: string, isMatchCase?: boolean, isContains?: boolean): boolean;
    /**
     * 一维数组去重
     * @param  {Array} arr  一维数组
     * @return {any[]} 去重后的一维数组
     * */
    arrayUnique<T>(arr: T[]): T[];
    /**
     * 复制文本，执行该函数，文本将会写入的粘贴板，后续用户可以进行粘贴操作
     * @param {String} string 需要复制的文本
     **/
    copyText(string: string): void;
    /**
     * 把\r\n换行符转成html的<br>换行符
     * @param {String} string 字符串
     * */
    rnTobr(string: string): string;
    /**
     *
     * 加粗匹配的关键字
     * @param str匹配的内容
     * @param key匹配关键字
     * @param color 可选 匹配关键字的颜色，默认为绿色;
     */
    boldKey(str: string, key: string | string[], color?: string): string;
    /**
     *首字母大字
     * @param {String}str 字符串
     * @param {Boolean}isWord 是否以单词为分界
     */
    capitalize(str: string, isWord?: boolean): string;
    /**
     * 判断元素是否在数组里
     * @param arr 原数组
     * @param item 元素
     * @return Boolean
     */
    inArray(arr: any[], item: any): boolean;
    /**
     * 从数组中删除元素，此操作会在原数中直接删除，只删除第一个匹配到的元素
     * @param arr 原数组
     * @param item 删除项
     * @return Array 如果删除成功，返回被删除的元素，失败返回undefault
     */
    removeArrayItem(arr: (string | number)[], item: string | number): (string | number)[] | undefined;
    isEmptyObject(obj: Object): boolean | undefined;
    getDomain(v: string): string;
    atToHtml(str: string, config?: AtToHtmlConfig): string;
    liveAction(actionType: ValueOf<typeof LiveActionType>, config?: LiveActionConfig): string;
    sleep(millisecond: number): Promise<unknown>;
    timeoutPerform(time: number): Perform;
    intervalPerform(time: number): (cb: Function) => void;
    nameToFirstLastName(name: string, id?: number): {
        last_name: string;
        first_name: string;
        gender: number;
    };
    matchSort(data: matchSortOption[], key: string, mkey: string): matchSortOption[];
    static fileType: {
        [key: string]: string;
    };
    removeEmoji(str: string): string;
    delSpecial(s: string): string;
    scopeRandom(min: number, max: number): number;
    getUrlParam(key: string, url?: string): string;
    createUrlParam(params: {
        [name: string]: string | number;
    }, url?: string): string;
    /**
     * 是否是字符串
     */
    isString(v: any): boolean;
    /**
     * 是否是boolean
     */
    isBoolean(v: any): boolean;
    isDomain(v: string): boolean;
    filterHTMLTag(msg: string): string;
    isIntranet(URL: string): boolean;
    getFullName(firstName: string, lastName: string): string;
    getWeChatType(str: string): 'qr' | 'img' | 'id';
    private static lastKey;
    getUniqueKey(): string;
    toLowerAndTrim(v: any): string;
    asyncDelay(time: number, maxTime?: number): Promise<unknown>;
    titleCase(str: string): string;
    isDesktopFiles(type: string): boolean;
    isExecl(type: string): boolean;
    formatCapital(num: string): string | 0;
    /**
     * 获取元素距离顶部的高度
     * @param el
     */
    getElementOffset(el: HTMLElement): {
        top: number;
        left: number;
    };
    getWebSite(text: string): {
        data: string[];
        text: string;
    };
    strToRegExp(str: string): RegExp | undefined;
}
declare let funs: Util;
export default funs;
